@@ -1,9 +1,9 @@
 # coding=utf-8
 #
 # This file is part of Hypothesis, which may be found at
-# https://github.com/HypothesisWorks/hypothesis-python
+# https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2017 David R. MacIver
+# Most of this work is copyright (C) 2013-2019 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,29 +15,27 @@
 #
 # END HEADER
 
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
 from hypothesis.internal.reflection import get_pretty_function_description
 from hypothesis.searchstrategy.strategies import SearchStrategy
 
 
 class FlatMapStrategy(SearchStrategy):
-
-    def __init__(
-        self, strategy, expand
-    ):
+    def __init__(self, strategy, expand):
         super(FlatMapStrategy, self).__init__()
         self.flatmapped_strategy = strategy
         self.expand = expand
 
-    def calc_is_empty(self):
-        return self.flatmapped_strategy.is_empty
+    def calc_is_empty(self, recur):
+        return recur(self.flatmapped_strategy)
 
     def __repr__(self):
-        if not hasattr(self, u'_cached_repr'):
-            self._cached_repr = u'%r.flatmap(%s)' % (
-                self.flatmapped_strategy, get_pretty_function_description(
-                    self.expand))
+        if not hasattr(self, u"_cached_repr"):
+            self._cached_repr = u"%r.flatmap(%s)" % (
+                self.flatmapped_strategy,
+                get_pretty_function_description(self.expand),
+            )
         return self._cached_repr
 
     def do_draw(self, data):
