@@ -1,9 +1,9 @@
 # coding=utf-8
 #
 # This file is part of Hypothesis, which may be found at
-# https://github.com/HypothesisWorks/hypothesis-python
+# https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2018 David R. MacIver
+# Most of this work is copyright (C) 2013-2019 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,64 +15,38 @@
 #
 # END HEADER
 
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
 import math
 
-import hypothesis.internal.conjecture.utils as d
 import hypothesis.internal.conjecture.floats as flt
+import hypothesis.internal.conjecture.utils as d
 from hypothesis.control import assume
-from hypothesis.internal.compat import int_from_bytes
+from hypothesis.internal.conjecture.utils import calc_label_from_name
 from hypothesis.internal.floats import sign
-from hypothesis.searchstrategy.strategies import SearchStrategy, \
-    MappedSearchStrategy
+from hypothesis.searchstrategy.strategies import SearchStrategy
 
 
-class IntStrategy(SearchStrategy):
+class WideRangeIntStrategy(SearchStrategy):
 
-    """A generic strategy for integer types that provides the basic methods
-    other than produce.
+    distribution = d.Sampler([4.0, 8.0, 1.0, 1.0, 0.5])
 
-    Subclasses should provide the produce method.
-
-    """
-
-
-class IntegersFromStrategy(SearchStrategy):
-
-    def __init__(self, lower_bound, average_size=100000.0):
-        super(IntegersFromStrategy, self).__init__()
-        self.lower_bound = lower_bound
-        self.average_size = average_size
+    sizes = [8, 16, 32, 64, 128]
 
     def __repr__(self):
-        return 'IntegersFromStrategy(%d)' % (self.lower_bound,)
+        return "WideRangeIntStrategy()"
 
     def do_draw(self, data):
-        return int(
-            self.lower_bound + d.geometric(data, 1.0 / self.average_size))
-
-
-class WideRangeIntStrategy(IntStrategy):
-
-    def __repr__(self):
-        return 'WideRangeIntStrategy()'
-
-    def do_draw(self, data):
-        size = 16
-        sign_mask = 2 ** (size * 8 - 1)
-
-        byt = data.draw_bytes(size)
-        r = int_from_bytes(byt)
-        negative = r & sign_mask
-        r &= (~sign_mask)
-        if negative:
+        size = self.sizes[self.distribution.sample(data)]
+        r = data.draw_bits(size)
+        sign = r & 1
+        r >>= 1
+        if sign:
             r = -r
         return int(r)
 
 
 class BoundedIntStrategy(SearchStrategy):
-
     """A strategy for providing integers in some interval with inclusive
     endpoints."""
 
@@ -82,25 +56,44 @@ class BoundedIntStrategy(SearchStrategy):
         self.end = end
 
     def __repr__(self):
-        return 'BoundedIntStrategy(%d, %d)' % (self.start, self.end)
+        return "BoundedIntStrategy(%d, %d)" % (self.start, self.end)
 
     def do_draw(self, data):
         return d.integer_range(data, self.start, self.end)
 
 
-NASTY_FLOATS = sorted([
-    0.0, 0.5, 1.1, 1.5, 1.9, 1.0 / 3, 10e6, 10e-6, 1.175494351e-38,
-    2.2250738585072014e-308,
-    1.7976931348623157e+308, 3.402823466e+38, 9007199254740992, 1 - 10e-6,
-    2 + 10e-6, 1.192092896e-07, 2.2204460492503131e-016,
-
-] + [float('inf'), float('nan')] * 5, key=flt.float_to_lex)
+NASTY_FLOATS = sorted(
+    [
+        0.0,
+        0.5,
+        1.1,
+        1.5,
+        1.9,
+        1.0 / 3,
+        10e6,
+        10e-6,
+        1.175494351e-38,
+        2.2250738585072014e-308,
+        1.7976931348623157e308,
+        3.402823466e38,
+        9007199254740992,
+        1 - 10e-6,
+        2 + 10e-6,
+        1.192092896e-07,
+        2.2204460492503131e-016,
+    ]
+    + [float("inf"), float("nan")] * 5,
+    key=flt.float_to_lex,
+)
 NASTY_FLOATS = list(map(float, NASTY_FLOATS))
 NASTY_FLOATS.extend([-x for x in NASTY_FLOATS])
 
+FLOAT_STRATEGY_DO_DRAW_LABEL = calc_label_from_name(
+    "getting another float in FloatStrategy"
+)
+
 
 class FloatStrategy(SearchStrategy):
-
     """Generic superclass for strategies which produce floats."""
 
     def __init__(self, allow_infinity, allow_nan):
@@ -111,13 +104,13 @@ class FloatStrategy(SearchStrategy):
         self.allow_nan = allow_nan
 
         self.nasty_floats = [f for f in NASTY_FLOATS if self.permitted(f)]
-        weights = [
-            0.6 * len(self.nasty_floats)
-        ] + [0.4] * len(self.nasty_floats)
+        weights = [0.2 * len(self.nasty_floats)] + [0.8] * len(self.nasty_floats)
         self.sampler = d.Sampler(weights)
 
     def __repr__(self):
-        return '%s()' % (self.__class__.__name__,)
+        return "{}(allow_infinity={}, allow_nan={})".format(
+            self.__class__.__name__, self.allow_infinity, self.allow_nan
+        )
 
     def permitted(self, f):
         assert isinstance(f, float)
@@ -129,7 +122,7 @@ class FloatStrategy(SearchStrategy):
 
     def do_draw(self, data):
         while True:
-            data.start_example()
+            data.start_example(FLOAT_STRATEGY_DO_DRAW_LABEL)
             i = self.sampler.sample(data)
             if i == 0:
                 result = flt.draw_float(data)
@@ -146,12 +139,10 @@ def float_order_key(k):
 
 
 class FixedBoundedFloatStrategy(SearchStrategy):
-
     """A strategy for floats distributed between two endpoints.
 
     The conditional distribution tries to produce values clustered
     closer to one of the ends.
-
     """
 
     def __init__(self, lower_bound, upper_bound):
@@ -162,21 +153,20 @@ class FixedBoundedFloatStrategy(SearchStrategy):
         lb = float_order_key(self.lower_bound)
         ub = float_order_key(self.upper_bound)
 
-        self.critical = [
-            z for z in (-0.0, 0.0)
-            if lb <= float_order_key(z) <= ub
-        ]
+        self.critical = [z for z in (-0.0, 0.0) if lb <= float_order_key(z) <= ub]
         self.critical.append(self.lower_bound)
         self.critical.append(self.upper_bound)
 
     def __repr__(self):
-        return 'FixedBoundedFloatStrategy(%s, %s)' % (
-            self.lower_bound, self.upper_bound,
+        return "FixedBoundedFloatStrategy(%s, %s)" % (
+            self.lower_bound,
+            self.upper_bound,
         )
 
     def do_draw(self, data):
         f = self.lower_bound + (
-            self.upper_bound - self.lower_bound) * d.fractional_float(data)
+            self.upper_bound - self.lower_bound
+        ) * d.fractional_float(data)
         assume(self.lower_bound <= f <= self.upper_bound)
         assume(sign(self.lower_bound) <= sign(f) <= sign(self.upper_bound))
         # Special handling for bounds of -0.0
@@ -184,16 +174,3 @@ class FixedBoundedFloatStrategy(SearchStrategy):
             if f == g:
                 f = math.copysign(f, g)
         return f
-
-
-class ComplexStrategy(MappedSearchStrategy):
-
-    """A strategy over complex numbers, with real and imaginary values
-    distributed according to some provided strategy for floating point
-    numbers."""
-
-    def __repr__(self):
-        return 'ComplexStrategy()'
-
-    def pack(self, value):
-        return complex(*value)
